@@ -2,7 +2,7 @@ package Log::Dispatch::Pipe;
 use 5.008001;
 use strict;
 use warnings;
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
 use Log::Dispatch 2.00;
 use parent 'Log::Dispatch::Output';
@@ -35,6 +35,10 @@ sub _open_handle {
     open my $fh, '|-', $self->{output_to}
         or die "Failed opening pipe: $!";
 
+    my $oldfh = select $fh;
+    $| = 1;
+    select $oldfh;
+
     binmode $fh, $self->{binmode}
         if $self->{binmode};
 
